@@ -3,7 +3,7 @@
 int
 main()
 {
-  char * a = malloc(10);
+  char * a = (char*) malloc(10);
   free(a);
   a[2]=123;
   free(malloc(2));
