@@ -1,6 +1,6 @@
 #include <stdlib.h>
 
-extern void * MALLOC(size_t n);
+void * MALLOC(size_t n);
 
 int
 main()
