@@ -4,13 +4,16 @@
 #include <string.h>
 #include <stdlib.h>
 
-extern void oops();
+#ifdef __cplusplus
+extern "C"
+#endif
+void oops();
 
 int main()
 {
   char * a;
 
-  a = malloc(13);
+  a = (char*)malloc(13);
   free(a);
   a = strdup("oops");		/* if libc is compiled with `-g' this
   			         * should give you the strdup symbol 
